pyparsing.pyparsing.OneOrMore

Package pyparsing :: Module pyparsing :: Class OneOrMore |
[frames | no frames]

## Type OneOrMore

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
                         OneOrMore

Repetition of one or more of the given expression.

Method Summary
| `__str__(self)`
| `parseImpl(self, instring, loc, doActions)`
| ``setResultsName`(self, name, listAllMatches)` Define name for referencing matching tokens as a nested attribute of the returned parse results.
Inherited from `ParseElementEnhance`: `__init__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `getException`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`list` | `__slotnames__` = `[]`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### setResultsName(self, name, listAllMatches=False) Define name for referencing matching tokens as a nested attribute of the returned parse results. NOTE: this returns a *copy* of the original ParserElement object; this is so that the client can define a basic element, such as an integer, and reference it in multiple places with different names. Overrides: `pyparsing.pyparsing.ParserElement.setResultsName` (inherited documentation)

Class Variable Details

    ### __slotnames__ Type: `list` Value:
        []

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net